#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2015. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # 定义与 gc_upgrade.sh 脚本参数相对应的环境变量及其缺省值
# #
# #===========================================================
# #
# # 在开始执行 gc_upgrade.sh 脚本时，将读取本文件。
# # 将为每个有效参数设置一个环境变量，并提供预定义的缺省值。
# #
# #
# # 用户可能希望修改缺省值，以便使用他们自己的值来
# # 启动 gc_upgrade.sh 脚本，
# # 而不必在命令行中手动输入参数及其相应值。
# #
# # 警告：
# # 并不需要为每个应用程序都设置所有变量。
# # 在修改值之前，请仔细阅读每条注释。
# #
# #
# #############################################################

# 参数：-oldApplicationHome
# 用法：-oldApplicationHome <目录路径>
# 描述：
# 	3.0.1 安装中的应用程序主目录的完整路径。
# 缺省值：
# 	<无>
# 约束：
#  - 这是一个必需参数
#  - <目录路径> 必须是以“server/conf”结尾的现有目录
#    例如，/QIBM/UserData/JazzTeamServer301Backup/server/conf
#
OLD_APPLICATION_HOME=

# 参数：-applicationContextRoot
# 用法：-applicationContextRoot <根目录>
# 描述：
# 	3.0.1 服务器的应用程序上下文根。
# 缺省值：
# 	gc
# 约束：
#  - <根目录> 必须是有效的目录单名（即，没有前导斜杠）
#
APPLICATION_CONTEXT_ROOT=

# 参数：-oldApplicationVersion
# 用法：-oldApplicationVersion <版本>
# 描述：
# 	要升级的 3.0.x 版本。缺省情况下，通过对旧的应用程序运行
#  repotools -version 来确定此版本。
# 缺省值：
# 	<无>
# 约束：
#  - 应该是完整的版本字符串
#    例如 3.0.0 或 3.0.1
#
OLD_APPLICATION_VERSION=

# 参数：-updateAppServerFiles
# 用法：-updateAppServerFiles <yes | no>
# 描述：
# 	指示是否更新缺省应用程序服务器 (WebSphere Liberty) 配置文件。
# 缺省值：
# 	yes
# 约束：
#  - 有效值只有“yes”和“no”
#
UPDATE_APPSERVER_FILES=yes

# 参数：-updateTomcatFiles
# 用法：-updateTomcatFiles <yes | no>
# 描述：
# 	指示是否更新 Tomcat 配置文件。
# 缺省值：
# 	no
# 约束：
#  - 有效值只有“yes”和“no”
#
UPDATE_TOMCAT_FILES=no

# 参数：-oldTomcatHome
# 用法：-oldTomcatHome <目录路径>
# 描述：
# 	3.0.1 安装中的 Tomcat 根目录的完整路径。
# 缺省值：
# 	<无>
# 约束：
#  - 必须是现有目录
#
OLD_TOMCAT_HOME=

# 参数：-newApplicationHome
# 用法：-newApplicationHome <目录路径>
# 描述：
# 	4.0 安装中的应用程序主目录的路径。
# 缺省值：
# 	conf
# 约束：
#  - 只有对 RTC、QM、GC 和 RM 进行升级才接受此参数
#  - 接受此参数时，这是必需参数
#  - <目录路径> 必须为以“server/conf”结尾的现有目录
#    例如，/Jazz/IBM/GC_6.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# 参数：-newJTSHome
# 用法：-newJTSHome <目录路径>
# 描述：
# 	4.0 安装中的 JTS 主目录的完整路径。
# 缺省值：
# 	新的应用程序主目录
# 约束：
#  - <目录路径> 必须是以“server/conf”结尾的现有目录
#    例如，/Jazz/IBM/GC_6.0/JazzTeamServer/server/conf
#
NEW_JTS_HOME=

# 参数：-jtsContextRoot
# 用法：-jtsContextRoot <根目录>
# 描述：
# 	4.0 JTS 服务器的上下文根。
# 缺省值：
# 	jts
# 约束：
#  - <根目录> 必须是有效的目录单名（即，没有前导斜杠）
#
JTS_CONTEXT_ROOT=jts

# 参数：-newApplicationTomcatHome
# 用法：-newApplicationTomcatHome <目录路径>
# 描述：
# 	4.0 安装中的应用程序 Tomcat 根目录的路径。
# 缺省值：
# 	<无>
#
NEW_TOMCAT_HOME=

# 参数：-newJTSTomcatHome
# 用法：-newJTSTomcatHome <目录路径>
# 描述：
# 	4.0 安装中的 JTS Tomcat 根目录的路径。
# 缺省值：
# 	<无>
#
NEW_JTS_TOMCAT_HOME=

# 参数：-ignoreJTSVersionCheck
# 用法：-ignoreJTSVersionCheck
# 描述：
#   不尝试验证应用程序版本与位于 newJTSHome 中的 Jazz Team Server 版本是否兼容。
# 缺省值：
# 	<无>
# 约束：
#  - 有效值只有“ignoreJTSVersionCheck”或者为空
#
IGNORE_JTS_VERSION_CHECK=

# 参数：-noPrompt
# 用法：-noPrompt
# 描述：
# 	在创建或修改表之前不提示
# 缺省值：
# 	noPrompt
# 约束：
#  - 有效值只有“noPrompt”或者为空
#
# NO_PROMPT=
NO_PROMPT=noPrompt

# 参数：-noVerify
# 用法：-noVerify
# 描述：
# 	不对 teamserver.properties 文件执行验证。
# 缺省值：
#   noVerify
# 约束：
#  - 有效值只有“noVerify”或者为空
#
# NO_VERIFY=
NO_VERIFY=noVerify

# 参数：-noStepPrompt
# 用法：-noStepPrompt
# 描述：
# 	执行步骤之前不提示。
# 缺省值：
#   false
# 约束：
#  - 有效值只有“true”和“false”
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# 参数：-noEditor
# 用法：-noEditor
# 描述：
#   不要用编辑器打开 teamserver.properties 文件。
# 缺省值：
#   false
# 约束：
#  - 有效值只有“true”和“false”
#
# NO_EDITOR=false
NO_EDITOR=false


# 参数：-noResumePrompt
# 用法：-noResumePrompt
# 描述：
#   恢复步骤前不提示。
# 缺省值：
#   false
# 约束：
#  - 有效值只有“true”和“false”
#
# NO_RESUME_PROMPT=false
NO_RESUME_PROMPT=false
