#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  © Copyright IBM Corporation 2006, 2015. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # qm_upgrade.sh スクリプト・パラメーターとそのデフォルト
# # 値に対応する環境変数の定義
# #
# #===========================================================
# #
# # このファイルは、qm_upgrade.sh スクリプトの実行の開始時に
# # 読み取られます。 このファイルで、有効なパラメーターごと
# # に、1 つの環境変数と定義済みのデフォルト値が設定されます。
# #
# # ユーザーは、デフォルト値を変更して qm_upgrade.sh スクリ
# # プトを独自の値で起動することもできます。そうすれば、コマン
# # ド行でパラメーターとそれに対応する値を手動で入力する必要
# # はありません。
# #
# # 警告:
# # すべてのアプリケーションにすべての変数を設定する必要は
# # ありません。値を変更する前に、それぞれのコメントを注意
# # 深くお読みください。
# #
# #############################################################

# パラメーター: -oldApplicationHome
# 使用法: -oldApplicationHome <ディレクトリー・パス>
# 説明:
# 	旧インストール済み環境でのアプリケーション・ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 制約:
#  - これは必須パラメーターです
#  - <ディレクトリー・パス> は「server/conf」で終わる既存のディレクトリーでなければなりません
#    例: /Jazz/IBM/RQM_3.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# パラメーター: -applicationContextRoot
# 使用法: -applicationContextRoot <ルート>
# 説明:
# 	アプリケーション・コンテキスト・ルート。
# デフォルト:
# 	qm
# 制約:
#  - <ルート> は有効な単一のディレクトリー名 (つまり前にスラッシュがないもの) でなければなりません
#
APPLICATION_CONTEXT_ROOT=

# パラメーター: -oldApplicationVersion
# 使用法: -oldApplicationVersion <バージョン>
# 説明:
# 	アップグレードするバージョン。デフォルトでは、古いアプリケーションに対して
#     repotools -version を実行する操作でこの値が判別されます。
# デフォルト:
# 	<なし>
# 制約:
#  - 完全なバージョン・ストリング
#    (3.0.0 や 3.0.1 など) にしてください
#
OLD_APPLICATION_VERSION=

# パラメーター: -updateAppServerFiles
# 使用法: -updateAppServerFiles <yes | no>
# 説明:
# 	デフォルトのアプリケーション・サーバー (WebSphere Liberty) 構成ファイルを更新するかどうか。
# デフォルト:
# 	yes
# 制約:
#  - 有効な値は「yes」および「no」のみです。
#
UPDATE_APPSERVER_FILES=yes

# パラメーター: -updateTomcatFiles
# 使用法: -updateTomcatFiles <yes | no>
# 説明:
# 	Tomcat 構成ファイルを更新するかどうか。
# デフォルト:
# 	no
# 制約:
#  - 有効な値は「yes」および「no」のみです。
#
UPDATE_TOMCAT_FILES=no

# パラメーター: -oldTomcatHome
# 使用法: -oldTomcatHome <ディレクトリー・パス>
# 説明:
# 	旧インストール済み環境での Tomcat ルート・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 制約:
#  - 既存のディレクトリーでなければなりません
#
OLD_TOMCAT_HOME=

# パラメーター: -newApplicationHome
# 使用法: -newApplicationHome <ディレクトリー・パス>
# 説明:
# 	新規インストール済み環境でのアプリケーション・ホーム・ディレクトリーへのパス。
# デフォルト:
# 	conf
# 制約:
#  - RTC、QM、および RM のアップグレードの場合のみ受諾されます
#  - 受諾された場合、これは必須パラメーターとなります
#  - <ディレクトリー・パス> は「server/conf」で終わる既存のディレクトリーでなければなりません
#    例: /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# パラメーター: -newJTSHome
# 使用法: -newJTSHome <ディレクトリー・パス>
# 説明:
# 	新規インストール済み環境で使用される、JTS 内の JTS ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	新規アプリケーション・ホーム・ディレクトリー
# 制約:
#  - <ディレクトリー・パス> は「server/conf」で終わる既存のディレクトリーでなければなりません
#    例: /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf
#
NEW_JTS_HOME=

# パラメーター: -jtsContextRoot
# 使用法: -jtsContextRoot <ルート>
# 説明:
# 	JTS サーバーのコンテキスト・ルート。
# デフォルト:
# 	jts
# 制約:
#  - <ルート> は有効な単一のディレクトリー名 (つまり前にスラッシュがないもの) でなければなりません
#
JTS_CONTEXT_ROOT=jts

# パラメーター: -newApplicationTomcatHome
# 使用法: -newApplicationTomcatHome <ディレクトリー・パス>
# 説明:
# 	新規インストール済み環境でのアプリケーション Tomcat ルート・ディレクトリーへのパス。
# デフォルト:
# 	<なし>
#
NEW_TOMCAT_HOME=

# パラメーター: -newJTSTomcatHome
# 使用法: -newJTSTomcatHome <ディレクトリー・パス>
# 説明:
# 	新規インストール済み環境で使用される、JTS 内の JTS Tomcat ルート・ディレクトリーへのパス。
# デフォルト:
# 	<なし>
#
NEW_JTS_TOMCAT_HOME=

# パラメーター: -noPrompt
# 使用法: -noPrompt
# 説明:
# 	表を作成または変更する前にプロンプトを出しません。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効な値は空、または「noPrompt」のみです
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# パラメーター: -noVerify
# 使用法: -noVerify
# 説明
# 	teamserver.properties ファイルの検査を実行しません。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効な値は空、または「noVerify」のみです
#
# NO_VERIFY=noVerify
NO_VERIFY=

# パラメーター: -noStepPrompt
# 使用法: -noStepPrompt
# 説明:
# 	ステップを実行する前にプロンプトを出しません。
# デフォルト:
# 	false
# 制約:
#  - 有効な値は「true」および「false」のみです。
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# パラメーター: -noEditor
# 使用法: -noEditor
# 説明:
#   teamserver.properties ファイルに対してエディターを開かない。
# デフォルト:
# 	false
# 制約:
#  - 有効な値は「true」および「false」のみです。
#
# NO_EDITOR=false
NO_EDITOR=false

# パラメーター: -noResumePrompt
# 使用法: -noResumePrompt
# 説明:
#   ステップを再開する前にプロンプトを出しません。
# デフォルト:
# 	false
# 制約:
#  - 有効な値は「true」および「false」のみです。
#
# NO_RESUME_PROMPT=false
NO_RESUME_PROMPT=false
