@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2015. All Rights Reserved.
rem
rem  Note to U.S. Government Users Restricted Rights:
rem  Use, duplication or disclosure restricted by GSA ADP Schedule
rem  Contract with IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Umgebungsvariablen gem den Parametern und Standardwerten
REM # im Script gc_upgrade.bat definieren
REM #
REM #===========================================================
REM #
REM # Diese Datei wird zu Beginn der Ausfhrung des Scripts
REM # gc_upgrade.bat gelesen. Pro gltigem Parameter wird eine
REM # Umgebungsvariable mit vordefiniertem Standardwert gesetzt.
REM #
REM # Benutzer knnen den Standardwert modifizieren und das
REM # Script gc_upgrade.bat mit eigenen Werten starten. Die
REM # Parameter und ihre Werte mssen dann nicht manuell in
REM # der Befehlszeile eingegeben werden.
REM #
REM # WARNUNG:
REM # Nicht alle Variablen mssen fr jede Anwendung gesetzt
REM # werden. Modifizieren Sie einen Wert erst, nachdem Sie
REM # sorgfltig den zugehrigen Kommentar gelesen haben.
REM #
REM #############################################################

rem Parameter: -oldApplicationHome
rem Syntax: -oldApplicationHome <Verzeichnispfad>
rem Beschreibung:
rem Vollstndiger Pfad zum Ausgangsverzeichnis der Anwendung in der alten Installation.
rem Standardwert:
rem 	<ohne>
rem Einschrnkungen:
rem  - Dies ist ein obligatorischer Parameter.
rem  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit 'server\conf' endet,
rem    z. B. D:\Jazz\IBM\GC_6.x\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parameter: -applicationContextRoot
rem Syntax: -applicationContextRoot <Stammverzeichnis>
rem Beschreibung:
rem 	Kontextstammverzeichnis der Anwendung.
rem Standardwert:
rem 	gc
rem Einschrnkungen:
rem  - <Stammverzeichnis> muss ein gltiger Verzeichnisname sein, d. h. ohne vorangestellten Schrgstrich.
rem
set APPLICATION_CONTEXT_ROOT=

rem Parameter: -oldApplicationVersion
rem Syntax: -oldApplicationVersion <Version>
rem Beschreibung:
rem 	Die GC-Version, fr die das Upgrade durchgefhrt wird. Standardmig wird
rem die Version mit repotools -version fr die alte Anwendung ermittelt.
rem Standardwert:
rem 	<ohne>
rem Einschrnkungen:
rem  -  Es muss sich um eine vollstndige Versionszeichenfolge handeln,
rem    z. B. 3.0.1
rem
set OLD_APPLICATION_VERSION=

rem Parameter: -updateAppServerFiles
rem Syntax: -updateAppServerFiles <yes | no>
rem Beschreibung:
rem 	Angabe, ob die Konfigurationsdateien fr den Standardanwendungsserver (WebSphere Liberty) aktualisiert werden sollen.
rem Standardwert:
rem 	yes
rem Einschrnkungen:
rem  - Gltig sind nur die Werte 'yes' und 'no'.
rem
set UPDATE_APPSERVER_FILES=yes

rem Parameter: -updateTomcatFiles
rem Syntax: -updateTomcatFiles <yes | no>
rem Beschreibung:
rem 	Angabe, ob die Tomcat-Konfigurationsdateien aktualisiert werden sollen.
rem Standardwert:
rem 	no
rem Einschrnkungen:
rem  - Gltig sind nur die Werte 'yes' und 'no'.
rem
set UPDATE_TOMCAT_FILES=no

rem Parameter: -oldTomcatHome
rem Syntax: -oldTomcatHome <Verzeichnispfad>
rem Beschreibung:
rem 	Vollstndiger Pfad zum Tomcat-Stammverzeichnis der alten Installation.
rem Standardwert:
rem 	<ohne>
rem Einschrnkungen:
rem  - Das Verzeichnis muss vorhanden sein.
rem
set OLD_TOMCAT_HOME=

rem Parameter: -newApplicationHome
rem Syntax: -newApplicationHome <Verzeichnispfad>
rem Beschreibung:
rem 	Pfad zum Ausgangsverzeichnis fr Anwendungen in der neuen Installation.
rem Standardwert:
rem 	conf
rem Einschrnkungen:
rem  - Nur fr RTC-, QM-, RM- und GC-Upgrades akzeptiert und
rem  - in diesen Fllen ein obligatorischer Parameter
rem  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit 'server\conf' endet,
rem    z. B. D:\Jazz\IBM\GC_6.0\JazzTeamServer\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parameter: -newJTSHome
rem Syntax: -newJTSHome <Verzeichnispfad>
rem Beschreibung:
rem 	Vollstndiger Pfad zum JTS-Ausgangsverzeichnis des von der neuen Installation verwendeten JTS.
rem Standardwert:
rem 	Ausgangsverzeichnis der neuen Anwendung
rem Einschrnkungen:
rem  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
rem    'server\conf' endet, z. B. D:\Jazz\IBM\GC_6.0\JazzTeamServer\server\conf.
rem
set NEW_JTS_HOME=

rem Parameter: -jtsContextRoot
rem Syntax: -jtsContextRoot <Stammverzeichnis>
rem Beschreibung:
rem 	Kontextstammverzeichnis des JTS-Servers.
rem Standardwert:
rem 	jts
rem Einschrnkungen:
rem   - <Stammverzeichnis> muss ein gltiger Verzeichnisname sein, d. h. ohne vorangestellten Schrgstrich.
rem
set JTS_CONTEXT_ROOT=jts

rem Parameter: -newApplicationTomcatHome
rem Syntax: -newApplicationTomcatHome <Verzeichnispfad>
rem Beschreibung:
rem 	Pfad zum Tomcat-Stammverzeichnis fr Anwendungen in der neuen Installation.
rem Standardwert:
rem 	<ohne>
rem
set NEW_TOMCAT_HOME=

rem Parameter: -newJTSTomcatHome
rem Syntax: -newJTSTomcatHome <Verzeichnispfad>
rem Beschreibung:
rem 	Pfad zum Tomcat-Stammverzeichnis fr den von der neuen Installation verwendeten JTS.
rem Standardwert:
rem 	<ohne>
rem
set NEW_JTS_TOMCAT_HOME=

rem Parameter: -noPrompt
rem Syntax: -noPrompt
rem Beschreibung:
rem 	Vor dem Erstellen oder Modifizieren der Tabellen keine Besttigung anfordern
rem Standardwert:
rem 	<ohne>
rem Einschrnkungen:
rem  - Die einzigen gltigen Werte sind ein leerer Wert und 'noPrompt'.
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parameter: -noVerify
rem Syntax: -noVerify
rem Beschreibung:
rem 	Keine Verifizierung der Dateien mit Team-Server-Eigenschaften.
rem Standardwert:
rem 	<ohne>
rem Einschrnkungen:
rem  - Gltig sind nur ein leerer Wert und 'noVerify'.
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parameter: -noStepPrompt
rem Syntax: -noStepPrompt
rem Beschreibung:
rem 	Vor Ausfhrung eines Schritts keine Besttigung anfordern.
rem Standardwert:
rem 	false
rem Einschrnkungen:
rem  - Gltig sind nur die Werte 'true' und 'false'.
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false


rem Parameter: -noStepPrompt
rem Syntax: -noStepPrompt
rem Beschreibung:
rem 	Keine Besttigung fr die Ausfhrung eines Schritts anfordern
rem Standardwert:
rem 	false
rem Einschrnkungen:
rem  - Gltig sind nur die Werte 'true' und 'false'.
rem
rem set NO_EDITOR=false
set NO_EDITOR=false


rem Parameter: -noResumePrompt
rem Syntax: -noResumePrompt
rem Beschreibung:
rem     Keine Besttigung fr die Wiederaufnahme eines Schritts anfordern.
rem Standardwert:
rem 	false
rem Einschrnkungen:
rem  - Gltig sind nur die Werte 'true' und 'false'.
rem
rem set NO_RESUME_PROMPT=false
set NO_RESUME_PROMPT=false
