@echo off
rem *******************************************************************************
rem  Materiali su licenza - Propriet di IBM
rem  (c) Copyright IBM Corporation 2015. Tutti i diritti riservati.
rem
rem  Nota relativa a limitazioni dei diritti per gli utenti del Governo degli Stati Uniti:
rem  L'uso, la duplicazione o la divulgazione sono limitati dal GSA ADP Schedule
rem  Contract con IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Definizione delle variabili d'ambiente corrispondenti ai
REM # parametri dello script qc_upgrade.bat e ai relativi
REM # valori predefiniti
REM #===========================================================
REM #
REM # Questo file viene letto all'inizio dell'esecuzione dello
REM # qc_upgrade.bat. Esso imposta una variabile di
REM # ambiente per parametro valido con un valore predefinito.
REM #
REM # Gli utenti possono modificare il valore predefinito per
REM # avviare lo script gc_upgrade.bat con i propri valori
REM # senza dover immettere il parametro e il corrispondente
REM # valore manualmente sulla riga comandi.
REM #
REM # AVVERTENZA:
REM # Non tutte le variabili devono essere impostate in base
REM # all'applicazione aggiornata.  Leggere attentamente ogni commento
REM # prima di modificare il valore.
REM #
REM #############################################################

rem Parametro: -oldApplicationHome
rem Uso: -oldApplicationHome <percorso dir>
rem Descrizione:
rem Il percorso completo della directory home nell'installazione precedente.
rem Valore predefinito:
rem 	<nessun valore>
rem Limitazioni:
rem  - Questo  un parametro obbligatorio
rem  - <percorso dir> deve essere una directory esistente che termina con 'server\conf'
rem    ad esempio, D:\Jazz\IBM\GC_6.x\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parametro: -applicationContextRoot
rem Uso: -applicationContextRoot <root>
rem Descrizione:
rem 	la root di contesto dell'applicazione.
rem Valore predefinito:
rem 	gc
rem Limitazioni:
rem  - <root> deve essere un nome di directory valido (senza barre iniziali)
rem
set APPLICATION_CONTEXT_ROOT=

rem Parametro: -oldApplicationVersion
rem Uso: -oldApplicationVersion <versione>
rem Descrizione:
rem  La versione GC che viene aggiornata.  Per impostazione predefinita, questa 
rem determinata eseguendo repotools -version rispetto alla vecchia applicazione.
rem Valore predefinito:
rem 	<nessuno>
rem Limitazioni:
rem  - deve essere una stringa di versione completa
rem    ad esempio, 3.0.1
rem
set OLD_APPLICATION_VERSION=

rem Parametro: -updateAppServerFiles
rem Uso: -updateAppServerFiles <yes | no>
rem Descrizione:
rem 	Indica se aggiornare i file di configurazione del server delle applicazioni predefinito (WebSphere Liberty).
rem Valore predefinito:
rem 	yes
rem Limitazioni:
rem  - Gli unici valori validi sono 'yes' e 'no'
rem
set UPDATE_APPSERVER_FILES=yes

rem Parametro: -updateTomcatFiles
rem Uso: -updateTomcatFiles <yes | no>
rem Descrizione:
rem Indica se aggiornare i file di configurazione tomcat.
rem Valore predefinito:
rem 	no
rem Limitazioni:
rem  - Gli unici valori validi sono 'yes' e 'no'
rem
set UPDATE_TOMCAT_FILES=no

rem Parametro: -oldTomcatHome
rem Uso: -oldTomcatHome <percorso dir>
rem Descrizione:
rem Il percorso completo della directory root Tomcat nell'installazione old.
rem Valore predefinito:
rem 	<nessun valore>
rem Limitazioni:
rem  - Deve essere una directory esistente
rem
set OLD_TOMCAT_HOME=

rem Parametro: -newApplicationHome
rem Uso: -newApplicationHome <percorso dir>
rem Descrizione:
rem Il percorso della directory home dell'applicazione nella nuova installazione.
rem Valore predefinito:
rem 	conf
rem Limitazioni:
rem  - Accettato solo per aggiornamenti di RTC, QM e GC
rem  - Se accettato, questo  un parametro obbligatorio
rem  - <percorso dir> deve essere una directory esistente che termina con 'server\conf'
rem    ad esempio, D:\Jazz\IBM\GC_6.0\JazzTeamServer\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parametro: -newJTSHome
rem Uso: -newJTSHome <percorso dir>
rem Descrizione:
rem 	il percorso della directory home JTS nel JTS che sar utilizzato dalla nuova installazione.
rem Valore predefinito:
rem La nuova directory home dell'applicazione
rem Limitazioni:
rem  - <percorso dir> deve essere una directory esistente che termina con 'server\conf'
rem    ad esempio, D:\Jazz\IBM\GC_6.0\JazzTeamServer\server\conf
rem
set NEW_JTS_HOME=

rem Parametro: -jtsContextRoot
rem Uso: -jtsContextRoot <root>
rem Descrizione:
rem 	la root di contesto del server JTS.
rem Valore predefinito:
rem 	jts
rem Limitazioni:
rem  - <root> deve essere una singola directory valida (senza barra iniziale)
rem
set JTS_CONTEXT_ROOT=jts

rem Parametro: -newApplicationTomcatHome
rem Uso: -newApplicationTomcatHome <percorso dir>
rem Descrizione:
rem 	il percorso della directory root Tomcat dell'applicazione nella nuova installazione.
rem Valore predefinito:
rem 	<nessun valore>
rem
set NEW_TOMCAT_HOME=

rem Parametro: -newJTSTomcatHome
rem Uso: -newJTSTomcatHome <percorso dir>
rem Descrizione:
rem 	il percorso della directory root Tomcat JTS nel JTS che sar utilizzato dalla nuova installazione.
rem Valore predefinito:
rem 	<nessun valore>
rem
set NEW_JTS_TOMCAT_HOME=

rem Parametro: -noPrompt
rem Uso: -noPrompt
rem Descrizione:
rem Non richiede prima di creare o modificare le tabelle
rem Valore predefinito:
rem 	<nessun valore>
rem Limitazioni:
rem  - Gli unici valori validi sono il valore vuoto o 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parametro: -noVerify
rem Uso: -noVerify
rem Descrizione:
rem Non esegue la verifica dei file teamserver.properties.
rem Valore predefinito:
rem 	<nessun valore>
rem Limitazioni:
rem  - Gli unici valori validi sono il valore vuoto o 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parametro: -noStepPrompt
rem Uso: -noStepPrompt
rem Descrizione:
rem Non richiede prima di eseguire un passo.
rem Valore predefinito:
rem 	false
rem Limitazioni:
rem  - Gli unici valori validi sono 'true' e 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false

rem Parametro: -noEditor
rem Uso: -noEditor
rem Descrizione:
rem Non richiede prima di eseguire un passo.
rem Valore predefinito:
rem 	false
rem Limitazioni:
rem  - Gli unici valori validi sono 'true' e 'false'
rem
rem set NO_EDITOR=false
set NO_EDITOR=false

rem Parametro: -noResumePrompt
rem Uso: -noResumePrompt
rem Descrizione:
rem     Non visualizza richieste prima di eseguire un passo.
rem Impostazione predefinita:
rem     false
rem Vincoli:
rem  - Gli unici valori validi sono 'true' o 'false'
rem
rem set NO_RESUME_PROMPT=false
set NO_RESUME_PROMPT=false
