@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2015. Todos os direitos reservados.
rem
rem  Nota sobre Direitos Restritos para Usurios do Governo dos Estados Unidos:
rem  Uso, duplicao ou divulgao restritos pelo documento GSA ADP Schedule
rem  Contract com a IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Defina as variveis de ambiente correspondentes aos
REM # parmetros de script gc_upgrade.bat e seus valores padro
REM #
REM #===========================================================
REM #
REM # Este arquivo  lido no incio da execuo do script
REM # gc_upgrade.bat. Ele configura uma varivel de ambiente
REM # por parmetro vlido com um valor padro predefinido.
REM #
REM # Os usurios podem desejar modificar o valor padro para
REM # ativar o script gc_upgrade.bat com seus prprios valores
REM # sem precisar inserir o parmetro e seu
REM # valor correspondente manualmente na linha de comandos.
REM #
REM # AVISO:
REM # Nem todas as variveis precisam ser configuradas para todo
REM # aplicativo.  Leia cada comentrio cuidadosamente antes de modificar
REM # o valor.
REM #
REM #############################################################

rem Parmetro: -oldApplicationHome
rem Uso: -oldApplicationHome <dir path>
rem Descrio:
rem 	Caminho completo para o diretrio inicial do aplicativo na instalao antiga.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - este  um parmetro obrigatrio
rem  - <caminho_do_dir> deve ser um diretrio existente terminado por 'server\conf'
rem    Por exemplo, D:\Jazz\IBM\GC_6.x\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parmetro: -applicationContextRoot
rem Uso: -applicationContextRoot <root>
rem Descrio:
rem 	Raiz de contexto do aplicativo.
rem Padro:
rem 	gc
rem Restries:
rem  - <root> deve ser um nome nico de diretrio vlido (ou seja, sem barra  esquerda)
rem
set APPLICATION_CONTEXT_ROOT=

rem Parmetro: -oldApplicationVersion
rem Uso: -oldApplicationVersion <version>
rem Descrio:
rem 	A verso do GC que est sendo submetida a upgrade.  Por padro, isso 
rem     determinado executando repotools -version no aplicativo antigo.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - deve ser uma sequncia de verses completa
rem    por exemplo, 3.0.1
rem
set OLD_APPLICATION_VERSION=

rem Parmetro: -updateAppServerFiles
rem Uso: -updateAppServerFiles <yes | no>
rem Descrio:
rem 	Se deseja atualizar os arquivos de configurao do servidor de aplicativos padro (WebSphere Liberty).
rem Padro:
rem 	yes
rem Restries:
rem  - Os nicos valores vlidos so 'yes' e 'no'
rem
set UPDATE_APPSERVER_FILES=yes

rem Parmetro: -updateTomcatFiles
rem Uso: -updateTomcatFiles <yes | no>
rem Descrio:
rem 	Se  necessrio atualizar os arquivos de configurao tomcat.
rem Padro:
rem 	no
rem Restries:
rem  - Os nicos valores vlidos so 'yes' e 'no'
rem
set UPDATE_TOMCAT_FILES=no

rem Parmetro: -oldTomcatHome
rem Uso: -oldTomcatHome <dir path>
rem Descrio:
rem 	Caminho completo para o diretrio raiz do Tomcat na instalao antiga.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Deve ser um diretrio existente
rem
set OLD_TOMCAT_HOME=

rem Parmetro: -newApplicationHome
rem Uso: -newApplicationHome <dir path>
rem Descrio:
rem 	Caminho para o diretrio inicial do aplicativo na nova instalao.
rem Padro:
rem 	conf
rem Restries:
rem  - Aceito somente para upgrade do RTC, QM, RM e GC
rem  - Quando aceito, este  um parmetro obrigatrio
rem  - <caminho_do_dir> deve ser um diretrio existente terminado por 'server\conf'
rem    Por exemplo, D:\Jazz\IBM\GC_6.0\JazzTeamServer\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parmetro: -newJTSHome
rem Uso: -newJTSHome <dir path>
rem Descrio:
rem 	Caminho completo para o diretrio inicial do JTS no JTS que a nova instalao ir usar.
rem Padro:
rem 	O novo diretrio inicial do aplicativo
rem Restries:
rem  - <caminho_do_dir> deve ser um diretrio existente terminado por 'server\conf'
rem    Por exemplo, D:\Jazz\IBM\GC_6.0\JazzTeamServer\server\conf
rem
set NEW_JTS_HOME=

rem Parmetro: -jtsContextRoot
rem Uso: -jtsContextRoot <root>
rem Descrio:
rem 	Raiz de contexto do servidor JTS.
rem Padro:
rem 	jts
rem Restries:
rem  - <root> deve ser um nome nico de diretrio vlido (ou seja, sem barra dianteira)
rem
set JTS_CONTEXT_ROOT=jts

rem Parmetro: -newApplicationTomcatHome
rem Uso: -newApplicationTomcatHome <dir path>
rem Descrio:
rem 	Caminho para o diretrio-raiz do aplicativo Tomcat na nova instalao.
rem Padro:
rem 	<nenhum>
rem
set NEW_TOMCAT_HOME=

rem Parmetro: -newJTSTomcatHome
rem Uso: -newJTSTomcatHome <dir path>
rem Descrio:
rem 	Caminho para o diretrio-raiz do Tomcat do JTS no JTS que a nova instalao ir usar.
rem Padro:
rem 	<nenhum>
rem
set NEW_JTS_TOMCAT_HOME=

rem Parmetro: -noPrompt
rem Uso: -noPrompt
rem Descrio:
rem 	No solicite antes de criar ou modificar as tabelas
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Os nicos valores vlidos so empty ou 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parmetro: -noVerify
rem Uso: -noVerify
rem Descrio:
rem  No execute a verificao de arquivos teamserver.properties.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Os nicos valores vlidos so vazio ou 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parmetro: -noStepPrompt
rem Uso: -noStepPrompt
rem Descrio:
rem 	No avisar antes de executar uma etapa.
rem Padro:
rem 	false
rem Restries:
rem  - Os nicos valores vlidos so 'true' e 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false

rem Parmetro: -noEditor
rem Uso: -noEditor
rem Descrio:
rem     No solicitar antes de executar uma etapa.
rem Padro:
rem     false
rem Restries:
rem  - Os nicos valores vlidos so 'true' ou 'false'
rem
rem set NO_EDITOR=false
set NO_EDITOR=false

rem Parmetro: -noResumePrompt
rem Uso: -noResumePrompt
rem Descrio:
rem     No exibir um prompt antes da continuao de uma etapa.
rem Padro:
rem     false
rem Restries:
rem  - Os nicos valores vlidos so 'true' ou 'false'
rem
rem set NO_RESUME_PROMPT=false
set NO_RESUME_PROMPT=false
