@echo off
rem *******************************************************************************
rem  Materiales bajo licencia - Propiedad de IBM
rem  (c) Copyright IBM Corporation 2006, 2015. Reservados todos los derechos.
rem
rem  Note to U.S. Government Users Restricted Rights:
rem  Use, duplication or disclosure restricted by GSA ADP Schedule
rem  Contract with IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Defina las variables de entorno correspondientes a los
REM # parmetros del script qm_upgrade.bat y sus valores
REM # predeterminados.
REM #===========================================================
REM #
REM # Este archivo se lee al comienzo de la ejecucin del
REM # script qm_upgrade.bat. Define una variable de entorno por
REM # cada parmetro vlido con un valor predeterminado
REM #
REM # Es posible que los usuarios deseen modificar el valor predeterminado
REM # para lanzar el script qm_upgrade.bat con sus propios valores
REM # sin tener que especificar de forma manual el parmetro y su
REM # valor correspondiente en la lnea de mandatos.
REM #
REM # AVISO:
REM # No es necesario definir todas las variables para cada
REM # aplicacin.  Lea cada comentario detenidamente antes de modificar
REM # el valor.
REM #
REM #############################################################

rem Parmetro: -oldApplicationHome
rem Uso: -oldApplicationHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso completa al directorio de inicio de la aplicacin en la instalacin anterior.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - es un parmetro obligatorio
rem  - <va acceso dir> dege ser un directorio existente terminado en 'server\conf'
rem    por ej. D:\Jazz\IBM\RQM_3.x\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parmetro: -applicationContextRoot
rem Uso: -applicationContextRoot <raz>
rem Descripcin:
rem 	Raz de contexto de aplicacin.
rem Valor predeterminado:
rem 	qm
rem Restricciones:
rem  - <raz> debe ser un nombre nico de directorio vlido (por ejemplo, sin ninguna barra inclinada inicial)
rem
set APPLICATION_CONTEXT_ROOT=

rem Parmetro: -oldApplicationVersion
rem Uso: -oldApplicationVersion <version>
rem Descripcin:
rem 	La versin de QM que se est actualizando.  De forma predeterminada, se
rem     determina ejecutando repotools -version en la aplicacin anterior.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - debe ser una serie de versin completa
rem    por ej. 3.0.1
rem
set OLD_APPLICATION_VERSION=

rem Parmetro: -updateAppServerFiles
rem Uso: -updateAppServerFiles <yes | no>
rem Descripcin:
rem 	Indica si se deben actualizar los archivos de configuracin del servidor de aplicaciones predeterminado (WebSphere Liberty).
rem Predeterminado:
rem 	yes
rem Restricciones:
rem  - Los nicos valores vlidos son 'yes' y 'no'
rem
set UPDATE_APPSERVER_FILES=yes

rem Parmetro: -updateTomcatFiles
rem Uso: -updateTomcatFiles <yes | no>
rem Descripcin:
rem 	Si deben actualizarse los archivos de configuracin tomcat.
rem Predeterminado:
rem 	no
rem Restricciones:
rem  - Los nicos valores vlidos son 'yes' y 'no'
rem
set UPDATE_TOMCAT_FILES=no

rem Parmetro: -oldTomcatHome
rem Uso: -oldTomcatHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso completa al directorio raz de Tomcat en la instalacin anterior.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Debe ser un directorio existente
rem
set OLD_TOMCAT_HOME=

rem Parmetro: -newApplicationHome
rem Uso: -newApplicationHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso al directorio de inicio de la aplicacin de la nueva instalacin.
rem Valor predeterminado:
rem 	conf
rem Restricciones:
rem  - Solo se acepta en actualizaciones RTC, QM y RM
rem  - Cuando se acepta, es un parmetro obligatorio
rem  - <va_acceso_dir> debe ser un directorio existente que termine en 'server\conf'
rem    por ej. D:\Jazz\IBM\RQM_3.0\JazzTeamServer\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parmetro: -newJTSHome
rem Uso: -newJTSHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso completa al directorio de inicio de JTS del JTS que la nueva instalacin utilizar.
rem Valor predeterminado:
rem 	El nuevo directorio de inicio de aplicacin
rem Restricciones:
rem  - <va_acceso_dir> debe ser un directorio existente que termine en 'server\conf'
rem    por ej. D:\Jazz\IBM\RQM_3.0\JazzTeamServer\server\conf
rem
set NEW_JTS_HOME=

rem Parmetro: -jtsContextRoot
rem Uso: -jtsContextRoot <raz>
rem Descripcin:
rem 	Raz de contexto del servidor JTS.
rem Valor predeterminado:
rem 	jts
rem Restricciones:
rem  - <raz> debe ser un nombre nico de directorio vlido (es decir, ninguna barra inclinada inicial)
rem
set JTS_CONTEXT_ROOT=jts

rem Parmetro: -newApplicationTomcatHome
rem Uso: -newApplicationTomcatHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso al directorio raz de Tomcat de la aplicacin de la nueva instalacin.
rem Valor predeterminado:
rem 	<ninguno>
rem
set NEW_TOMCAT_HOME=

rem Parmetro: -newJTSTomcatHome
rem Uso: -newJTSTomcatHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso al directorio raz de Tomcat de JTS del JTS que la nueva instalacin utilizar.
rem Valor predeterminado:
rem 	<ninguno>
rem
set NEW_JTS_TOMCAT_HOME=

rem Parmetro: -noPrompt
rem Uso: -noPrompt
rem Descripcin:
rem 	No mostrar solicitud antes de crear o modificar las tablas
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Los nicos valores vlidos son en blanco o 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parmetro: -noVerify
rem Uso: -noVerify
rem Descripcin:
rem 	No realizar verificacin de los archivos teamserver.properties.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Los nicos valores vlidos son en blanco o 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parmetro: -noStepPrompt
rem Uso: -noStepPrompt
rem Descripcin:
rem 	No mostrar solicitud antes de ejecutar un paso.
rem Valor predeterminado:
rem 	false
rem Restricciones:
rem  - Los nicos valores vlidos son 'true' o 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false

rem Parmetro: -noEditor
rem Uso: -noEditor
rem Descripcin:
rem     No mostrar solicitud antes de ejecutar un paso.
rem Valor predeterminado:
rem     false
rem Restricciones:
rem  - Los nicos valores vlidos son 'true' o 'false'
rem
rem set NO_EDITOR=false
set NO_EDITOR=false

rem Parmetro: -noResumePrompt
rem Uso: -noResumePrompt
rem Descripcin:
rem     No mostrar un indicador antes de que se reanude un paso.
rem Predeterminado:
rem     false
rem Restricciones:
rem  - Los nicos valores vlidos son 'true' o 'false'
rem
rem set NO_RESUME_PROMPT=false
set NO_RESUME_PROMPT=false
