@echo off
rem *******************************************************************************
rem  Materiales bajo licencia - Propiedad de IBM
rem  (c) Copyright IBM Corporation 2006, 2015. Reservados todos los derechos.
rem
rem  Note to U.S. Government Users Restricted Rights:
rem  Use, duplication or disclosure restricted by GSA ADP Schedule
rem  Contract with IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Defina las variables de entorno correspondientes a los
REM # parmetros del script rm_upgrade.bat y sus valores
REM # predeterminados.
REM #===========================================================
REM #
REM # Este archivo se lee al comienzo de la ejecucin del
REM # script rm_upgrade.bat. Define una variable de entorno por
REM # cada parmetro vlido con un valor predeterminado
REM #
REM # Es posible que los usuarios deseen modificar el valor predeterminado
REM # para lanzar el script rm_upgrade.bat con sus propios valores
REM # sin tener que especificar de forma manual el parmetro y su
REM # valor correspondiente en la lnea de mandatos.
REM #
REM # AVISO:
REM # No es necesario definir todas las variables para cada
REM # aplicacin.  Lea cada comentario detenidamente antes de modificar
REM # el valor.
REM #
REM #############################################################

rem Parmetro: -oldApplicationHome
rem Uso: -oldApplicationHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso completa al directorio de inicio de la aplicacin en la instalacin anterior.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - este parmetro es obligatorio
rem  - <va acceso dir> debe ser un directorio existente terminado en 'server\conf'
rem    por ejemplo D:\Jazz\IBM\RM_4.x\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parmetro: -applicationContextRoot
rem Uso: -applicationContextRoot <raz>
rem Descripcin:
rem 	Raz de contexto de aplicacin.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - <raz> debe ser un nombre nico de directorio vlido (por ejemplo, sin ninguna barra inclinada inicial)
rem
set APPLICATION_CONTEXT_ROOT=

rem Parmetro: -oldApplicationVersion
rem Uso: -oldApplicationVersion <versin>
rem Descripcin:
rem 	La versin de RM que se est actualizando.  De forma predeterminada, se
rem     determina ejecutando repotools -version en la aplicacin anterior.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - debe ser una serie de versin completa
rem    por ej. 3.0.1
rem
set OLD_APPLICATION_VERSION=

rem Parmetro: -updateAppServerFiles
rem Uso: -updateAppServerFiles <yes | no>
rem Descripcin:
rem 	Indica si se deben actualizar los archivos de configuracin del servidor de aplicaciones predeterminado (WebSphere Liberty).
rem Predeterminado:
rem 	yes
rem Restricciones:
rem  - Los nicos valores vlidos son 'yes' y 'no'
rem
set UPDATE_APPSERVER_FILES=yes

rem Parmetro: -updateTomcatFiles
rem Uso: -updateTomcatFiles <yes | no>
rem Descripcin:
rem 	Si deben actualizarse los archivos de configuracin tomcat.
rem Predeterminado:
rem 	no
rem Restricciones:
rem  - Los nicos valores vlidos son 'yes' y 'no'
rem
set UPDATE_TOMCAT_FILES=no

rem Parmetro: -oldApplicationTomcatHome
rem Uso: -oldApplicationTomcatHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso completa al directorio raz de Tomcat de la aplicacin de la instalacin anterior.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Solo se acepta para la actualizacin de RM
rem  - Debe ser un directorio existente
set OLD_TOMCAT_HOME=

rem Parmetro: -newApplicationHome
rem Uso: -newApplicationHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso al directorio de inicio de la aplicacin de la nueva instalacin.
rem Valor predeterminado:
rem 	conf
rem Restricciones:
rem  - Solo se acepta en actualizaciones RTC, QM y RM
rem  - Cuando se acepta, es un parmetro obligatorio
rem  - <va acceso dir> debe ser un directorio existente que termine en 'server\conf'
rem    por ejemplo D:\Jazz\IBM\RM_4.x\JazzTeamServer\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parmetro: -newJTSHome
rem Uso: -newJTSHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso completa al directorio de inicio de JTS del JTS que la nueva instalacin utilizar.
rem Valor predeterminado:
rem 	El nuevo directorio de inicio de aplicacin
rem Restricciones:
rem  - <va_acceso_dir> debe ser un directorio existente que termine en 'server\conf'
rem
set NEW_JTS_HOME=

rem Parmetro: -newJTSContextRoot
rem Uso: -newJTSContextRoot <raz>
rem Descripcin:
rem 	Raz de contexto del servidor JTS.
rem Valor predeterminado:
rem 	jts
rem Restricciones:
rem  - <raz> debe ser un nombre nico de directorio vlido (es decir, ninguna barra inclinada inicial)
rem
set JTS_CONTEXT_ROOT=jts

rem Parmetro: -newApplicationTomcatHome
rem Uso: -newApplicationTomcatHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso al directorio raz de Tomcat de la aplicacin de la nueva instalacin.
rem Valor predeterminado:
rem 	<ninguno>
rem
set NEW_TOMCAT_HOME=

rem Parmetro: -newJTSTomcatHome
rem Uso: -newJTSTomcatHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso al directorio raz de Tomcat de JTS del JTS que la nueva instalacin utilizar.
rem Valor predeterminado:
rem 	<ninguno>
rem
set NEW_JTS_TOMCAT_HOME=

rem Parmetro: -noPrompt
rem Uso: -noPrompt
rem Descripcin:
rem 	No solicita confirmacin (es decir, utiliza siempre noPrompt) al ejecutar mandatos repotools
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Los nicos valores vlidos estn vacos o son 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parmetro: -noVerify
rem Uso: -noVerify
rem Descripcin:
rem 	No realizar verificacin de los archivos teamserver.properties.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Los nicos valores vlidos son en blanco o 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parmetro: -noStepPrompt
rem Uso: -noStepPrompt
rem Descripcin:
rem 	No mostrar solicitud antes de ejecutar un paso.
rem Valor predeterminado:
rem 	false
rem Restricciones:
rem  - Los nicos valores vlidos son 'true' o 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false

rem Parmetro: -noEditor
rem Uso: -noEditor
rem Descripcin:
rem     No mostrar solicitud antes de ejecutar un paso.
rem Valor predeterminado:
rem     false
rem Restricciones:
rem  - Los nicos valores vlidos son 'true' o 'false'
rem
rem set NO_EDITOR=false
set NO_EDITOR=false

rem Parmetro: -db.jdbc.location
rem Uso: -db.jdbc.location <JDBC_URL>
rem Descripcin:
rem 	Ubicacin JDBC de la base de datos de RM. (Solo es necesario al pasar de 4.x a 5.x)
rem		Ejemplos:
rem			DB2 		//localhost:50000/RM_DB:user=db2admin;password={password};
rem			DB2i 		//hostname;hold statements=true;metadata source=1;user=rmDBuser;password={password};
rem			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
rem			SQLSERVER	//localhost:1433;databaseName=RM_DB;user=rmDBuser;password={password};
rem			DERBY		conf/rm/derby/repositoryDB
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Solo se acepta para la actualizacin de RM desde la versin 4.x
rem
rem set DB_JDBC_LOCATION_VALUE=conf/rm/derby/repositoryDB
set DB_JDBC_LOCATION_VALUE=

rem Parmetro: -db.jdbc.password
rem Uso: -db.jdbc.password <CONTRASEA_JDBC>
rem Descripcin:
rem 	Contrasea (texto sin formato o cifrado) que se sustituir si aparece "{password}" en el URL de JDBC. 
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Se debe especificar si el URL de JDBC para la base de datos de RM contiene {password}
rem
set DB_JDBC_PASSWORD_VALUE=

rem Parmetro: -db.db2i.schema.name
rem Uso: -db.db2i.schema.name <SCHEMA_NAME>
rem Descripcin:
rem 	El nombre de esquema de la base de datos DB2i.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Debe especificarse utilizando el tipo de base de datos DB2i. 
rem
set DB_DB2I_SCHEMA_NAME_VALUE=

rem Parmetro: -db.db2.dsn.dbname
rem Uso: -db.db2.dsn.dbname <DSN_DBNAME>
rem Descripcin:
rem 	El nombre de base de datos DSN de DB2Z.
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Debe especificarse utilizando el tipo de base de datos DB2z. 
rem
set DB_DB2_DSN_DBNAME_VALUE=

rem Parmetro: -db.schemaPrefix
rem Uso: -db.schemaPrefix <SCHEMA_PREFIX>
rem Descripcin:
rem 	El prefijo de esquema de base de datos. 
rem Valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - Debe especificarse utilizando el tipo de base de datos DB2z. 
rem
set DB_SCHEMA_PREFIX_VALUE=

rem Parmetro: -oldJTSHome
rem Uso: -oldJTSHome <va acceso dir>
rem Descripcin:
rem 	Va de acceso completa al directorio de inicio de JTS en la instalacin anterior.
rem valor predeterminado:
rem 	<ninguno>
rem Restricciones:
rem  - <va acceso dir> debe ser un directorio existente terminado en 'server\conf'
rem  - Slo vlido para actualizaciones de RM y JTS
rem
set OLD_JTS_HOME=

rem Parmetro: -lpaContextRoot
rem Uso: -lpaContextRoot <raz>
rem Descripcin:
rem 	La raz de contexto de LPA
rem Valor predeterminado:
rem 	admin
rem Restricciones:
rem  - <raz> debe ser un nico nombre de directorio vlido (es decir, sin barra inclinada inicial)
rem
set LPA_CONTEXT_ROOT=admin

rem Parmetro: -noResumePrompt
rem Uso: -noResumePrompt
rem Descripcin:
rem     No mostrar un indicador antes de que se reanude un paso.
rem Predeterminado:
rem     false
rem Restricciones:
rem  - Los nicos valores vlidos son 'true' o 'false'
rem
rem set NO_RESUME_PROMPT=false
set NO_RESUME_PROMPT=false
