@echo off
rem *******************************************************************************
rem  Materiais Licenciados - Propriedade da IBM
rem  (c) Copyright IBM Corporation 2006, 2015. Todos os direitos reservados.
rem
rem  Nota sobre Direitos Restritos para Usurios do Governo dos Estados Unidos:
rem  Uso, duplicao ou divulgao restritos pelo documento GSA ADP Schedule
rem  Contract com a IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Defina as variveis de ambiente correspondentes aos
REM # parmetros de rm_upgrade.bat e seus valores padro
REM #
REM #===========================================================
REM #
REM # Este arquivo  lido no incio da execuo do script
REM # rm_upgrade.bat. Ele configura uma varivel de ambiente
REM # por parmetro vlido com um valor padro predefinido.
REM #
REM # Os usurios podem desejar modificar o valor padro para
REM # ativar o script rm_upgrade.bat com seus prprios valores
REM # sem precisar inserir o parmetro e seus
REM # valores correspondentes manualmente na linha de comandos.
REM #
REM # AVISO:
REM # Nem todas as variveis precisam ser configuradas para todo
REM # aplicativo.  Leia cada comentrio cuidadosamente antes de modificar
REM # o valor.
REM #
REM #############################################################

rem Parmetro: -oldApplicationHome
rem Uso: -oldApplicationHome <dir path>
rem Descrio:
rem 	Caminho completo para o diretrio inicial do aplicativo na instalao antiga.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Este  um parmetro obrigatrio
rem  - <caminho do diretrio> deve ser um diretrio existente finalizado por 'server\conf'
rem    por exemplo, D:\Jazz\IBM\RM_4.x\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parmetro: -applicationContextRoot
rem Uso: -applicationContextRoot <root>
rem Descrio:
rem 	Raiz de contexto do aplicativo.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - <root> deve ser um nome nico de diretrio vlido (ou seja, sem barra  esquerda)
rem
set APPLICATION_CONTEXT_ROOT=

rem Parmetro: -oldApplicationVersion
rem Uso: -oldApplicationVersion <version>
rem Descrio:
rem 	A verso do RM que est sendo submetida a upgrade.  Por padro, isso 
rem     determinado executando repotools -version no aplicativo antigo.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - deve ser uma sequncia de verses completa
rem    por exemplo, 3.0.1
rem
set OLD_APPLICATION_VERSION=

rem Parmetro: -updateAppServerFiles
rem Uso: -updateAppServerFiles <yes | no>
rem Descrio:
rem 	Se deseja atualizar os arquivos de configurao do servidor de aplicativos padro (WebSphere Liberty).
rem Padro:
rem 	yes
rem Restries:
rem  - Os nicos valores vlidos so 'yes' e 'no'
rem
set UPDATE_APPSERVER_FILES=yes

rem Parmetro: -updateTomcatFiles
rem Uso: -updateTomcatFiles <yes | no>
rem Descrio:
rem 	Se  necessrio atualizar os arquivos de configurao tomcat.
rem Padro:
rem 	no
rem Restries:
rem  - Os nicos valores vlidos so 'yes' e 'no'
rem
set UPDATE_TOMCAT_FILES=no

rem Parmetro: -oldApplicationTomcatHome
rem Uso: -oldApplicationTomcatHome <dir path>
rem Descrio:
rem 	Caminho completo para o diretrio-raiz do Tomcat do Aplicativo na instalao antiga.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Aceito somente para upgrade do RM
rem  - Deve ser um diretrio existente
rem
set OLD_TOMCAT_HOME=

rem Parmetro: -newApplicationHome
rem Uso: -newApplicationHome <dir path>
rem Descrio:
rem 	Caminho para o diretrio inicial do aplicativo na nova instalao.
rem Padro:
rem 	conf
rem Restries:
rem  - Aceito somente para upgrade do RTC, QM e RM
rem  - Quando aceito, este  um parmetro obrigatrio
rem  - <caminho do diretrio> deve ser um diretrio existente finalizado por 'server\conf'
rem    por exemplo, D:\Jazz\IBM\RM_4.x\JazzTeamServer\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parmetro: -newJTSHome
rem Uso: -newJTSHome <dir path>
rem Descrio:
rem 	Caminho completo para o diretrio inicial do JTS no JTS que a nova instalao ir usar.
rem Padro:
rem 	O novo diretrio inicial do aplicativo
rem Restries:
rem  - <dir path> deve ser um diretrio existente terminado por 'server\conf'
rem
set NEW_JTS_HOME=

rem Parmetro: -newJTSContextRoot
rem Uso: -newJTSContextRoot <root>
rem Descrio:
rem 	Raiz de contexto do servidor JTS.
rem Padro:
rem 	jts
rem Restries:
rem  - <root> deve ser um nome nico de diretrio vlido (ou seja, sem barra dianteira)
rem
set JTS_CONTEXT_ROOT=jts

rem Parmetro: -newApplicationTomcatHome
rem Uso: -newApplicationTomcatHome <dir path>
rem Descrio:
rem 	Caminho para o diretrio-raiz do aplicativo Tomcat na nova instalao.
rem Padro:
rem 	<nenhum>
rem
set NEW_TOMCAT_HOME=

rem Parmetro: -newJTSTomcatHome
rem Uso: -newJTSTomcatHome <dir path>
rem Descrio:
rem 	Caminho para o diretrio-raiz do Tomcat do JTS no JTS que a nova instalao ir usar.
rem Padro:
rem 	<nenhum>
rem
set NEW_JTS_TOMCAT_HOME=

rem Parmetro: -noPrompt
rem Uso: -noPrompt
rem Descrio:
rem 	No solicite confirmao (ex. sempre use noPrompt) ao executar qualquer comando repotools
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Os nicos valores vlidos so empty ou 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parmetro: -noVerify
rem Uso: -noVerify
rem Descrio:
rem  No execute a verificao de arquivos teamserver.properties.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Os nicos valores vlidos so vazio ou 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parmetro: -noStepPrompt
rem Uso: -noStepPrompt
rem Descrio:
rem 	No avisar antes de executar uma etapa.
rem Padro:
rem 	false
rem Restries:
rem  - Os nicos valores vlidos so 'true' e 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false

rem Parmetro: -noEditor
rem Uso: -noEditor
rem Descrio:
rem     No solicitar antes de executar uma etapa.
rem Padro:
rem     false
rem Restries:
rem  - Os nicos valores vlidos so 'true' ou 'false'
rem
rem set NO_EDITOR=false
set NO_EDITOR=false

rem Parmetro: -db.jdbc.location
rem Uso: -db.jdbc.location <JDBC_URL>
rem Descrio:
rem 	O local do JDBC para o banco de dados do RM. (Necessrio somente ao mover de 4.x para 5.x)
rem		Exemplos:
rem			DB2 		//localhost:50000/RM_DB:user=db2admin;password={password};
rem			DB2i 		//hostname;hold statements=true;metadata source=1;user=rmDBuser;password={password};
rem			ORACLE		thin:rmDBuser/{password}@//oracleserver.example.com:1521/RM_DB
rem			SQLSERVER	//localhost:1433;databaseName=RM_DB;user=rmDBuser;password={password};
rem			DERBY		conf/rm/derby/repositoryDB
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Aceito apenas para upgrade do RM de 4.x
rem
rem set DB_JDBC_LOCATION_VALUE=conf/rm/derby/repositoryDB
set DB_JDBC_LOCATION_VALUE=

rem Parmetro: -db.jdbc.password
rem Uso: -db.jdbc.password <SENHA_DO_JDBC>
rem Descrio:
rem 	A senha (texto simples ou criptografado) que ser substituta se "{password}" aparecer na URL do JDBC. 
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Deve ser especificada se a URL do JDBC para o banco de dados RM contiver {password}
rem
set DB_JDBC_PASSWORD_VALUE=

rem Parmetro: -db.db2i.schema.name
rem Uso: -db.db2i.schema.name <NOME_DO_ESQUEMA>
rem Descrio:
rem 	O nome do esquema do banco de dados DB2ie.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Deve ser especificado usando o tipo de banco de dados DB2i. 
rem
set DB_DB2I_SCHEMA_NAME_VALUE=

rem Parmetro: -db.db2.dsn.dbname
rem Uso: -db.db2.dsn.dbname <NOME_DO_BANCO_DE_DADOS_DSN>
rem Descrio:
rem 	O nome do banco de dados DSN do DB2Z.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Deve ser especificado usando o tipo de banco de dados DB2z. 
rem
set DB_DB2_DSN_DBNAME_VALUE=

rem Parmetro: -db.schemaPrefix
rem Uso: -db.schemaPrefix <PREFIXO_DO_ESQUEMA>
rem Descrio:
rem 	O prefixo do esquema do banco de dados. 
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - Deve ser especificado usando o tipo de banco de dados DB2z. 
rem
set DB_SCHEMA_PREFIX_VALUE=

rem Parmetro: -oldJTSHome
rem Uso: -oldJTSHome <dir path>
rem Descrio:
rem 	Caminho completo do diretrio inicial do JTS na instalao antiga.
rem Padro:
rem 	<nenhum>
rem Restries:
rem  - <dir path> deve ser um diretrio existente terminando com 'server\conf'
rem  - Somente vlido por upgrades do RM e JTS
rem
set OLD_JTS_HOME=

rem Parmetro: -lpaContextRoot
rem Uso: -lpaContextRoot <root>
rem Descrio:
rem 	A raiz de contexto do LPA
rem Padro:
rem 	admin
rem Restries:
rem  - <root> deve ser um nico nome de diretrio vlido (por exemplo, sem barra  esquerda)
rem
set LPA_CONTEXT_ROOT=admin

rem Parmetro: -noResumePrompt
rem Uso: -noResumePrompt
rem Descrio:
rem     No exibir um prompt antes da continuao de uma etapa.
rem Padro:
rem     false
rem Restries:
rem  - Os nicos valores vlidos so 'true' ou 'false'
rem
rem set NO_RESUME_PROMPT=false
set NO_RESUME_PROMPT=false
